==> fuel-ui-0.4.1-3.tgz: package/esm/directives/directives.demo.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuelUiModule } from "../fuel-ui";
import { AnimationDemo } from "./animation/animation.demo";
import { TooltipDemo } from "./tooltip/tooltip.demo";
import { CodeHighlighterDemo } from "./codeHighlighter/codeHighlighter.demo";
export * from "./animation/animation.demo";
export * from "./tooltip/tooltip.demo";
export * from "./codeHighlighter/codeHighlighter.demo";
const directivesDemoDirectives = [
    AnimationDemo,
    TooltipDemo,
    CodeHighlighterDemo
];
export let FuiDirectivesDemoModule = class FuiDirectivesDemoModule {
};
FuiDirectivesDemoModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            FuelUiModule
        ],
        declarations: directivesDemoDirectives,
        exports: directivesDemoDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiDirectivesDemoModule);

==> fuel-ui-0.4.1-5.tgz: package/esm/directives/directives.demo.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuelUiModule } from "../fuel-ui";
import { AnimationDemo } from "./Animation/Animation.Demo";
import { TooltipDemo } from "./Tooltip/Tooltip.Demo";
import { CodeHighlighterDemo } from "./CodeHighlighter/CodeHighlighter.Demo";
export * from "./Animation/Animation.Demo";
export * from "./Tooltip/Tooltip.Demo";
export * from "./CodeHighlighter/CodeHighlighter.Demo";
const directivesDemoDirectives = [
    AnimationDemo,
    TooltipDemo,
    CodeHighlighterDemo
];
export let FuiDirectivesDemoModule = class FuiDirectivesDemoModule {
};
FuiDirectivesDemoModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            FuelUiModule
        ],
        declarations: directivesDemoDirectives,
        exports: directivesDemoDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiDirectivesDemoModule);
